@@ -4,7 +4,7 @@ package Class::C3;
 use strict;
 use warnings;
 
-our $VERSION = '0.15_03';
+our $VERSION = '0.15_04';
 
 our $C3_IN_CORE;
 our $C3_XS;
@@ -253,18 +253,22 @@ Class::C3 - A pragma to use the C3 method resolution order algortihm
     D->can('hello')->();          # can() also works correctly
     UNIVERSAL::can('D', 'hello'); # as does UNIVERSAL::can()
 
-=head1 SPECIAL NOTE FOR 0.15_01
+=head1 SPECIAL NOTE FOR 0.15_04
 
 To try this with the experimental perl core c3 patch,
-download a recent copy perl-current:
+download the most recent copy perl-current:
 
-http://mirrors.develooper.com/perl/APC/perl-current-snap/perl-current@30943.tar.bz2
+http://mirrors.develooper.com/perl/APC/perl-current-snap/
 
-apply the enclosed c3.patch, and install this perl:
+Apply the latest C3 patch from:
+
+http://www.dtmf.com/c3-subgen.patch
+
+Then:
 
 sh Configure -Dusedevel -Dprefix=/where/I/want/it -d -e && make && make test && make install
 
-then try your C3-using software against this perl + Class::C3 0.15_01.
+then try your C3-using software against this perl + Class::C3 0.15_04.
 
 =head1 DESCRIPTION
 
